@@ -3,7 +3,7 @@ use warnings;
 
 package Mail::Message::Body;
 use vars '$VERSION';
-$VERSION = '2.053';
+$VERSION = '2.054';
 use base 'Mail::Reporter';
 
 use Mail::Message::Field;
@@ -74,11 +74,11 @@ sub init($)
     {
         if(!ref $data)
         {   my @lines = split /^/, $data;
-            $lines[-1] .= "\n" if @lines && substr($lines[-1], -1) ne "\n";
             $self->_data_from_lines(\@lines)
         }
         elsif(ref $data eq 'ARRAY')
-        {   $self->_data_from_lines($data) or return }
+        {   $self->_data_from_lines($data) or return;
+        }
         else
         {   croak "Illegal datatype for data option." }
     }
