@@ -3,6 +3,9 @@ package MailBox::Test::44imap::Definition;
 
 sub name     {"Mail::Box::IMAP; imap folders"}
 sub critical {0}
-sub skip     { undef }
+
+sub skip     {
+   !defined $ENV{USER} || $ENV{USER} ne 'markov'
+}
 
 1;
